# [Zope-tests] FAILED : Zope 3.4 Known Good Set / py2.5-64bit-linux

buildbot at pov.lt buildbot at pov.lt
Tue Feb 1 22:02:13 EST 2011

- Previous message: [Zope-tests] OK : Zope 3.4 Known Good Set / py2.4-32bit-linux
- Next message: [Zope-tests] OK : Bluebream / Python2.4.6 64bit linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    FAILED : Zope 3.4 Known Good Set / py2.5-64bit-linux
    Build: https://zope3.pov.lt/buildbot/builders/py2.5-64bit-linux/builds/911

    Build Reason: The Nightly scheduler named 'nightly2' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: https://zope3.pov.lt/buildbot/

- Previous message: [Zope-tests] OK : Zope 3.4 Known Good Set / py2.4-32bit-linux
- Next message: [Zope-tests] OK : Bluebream / Python2.4.6 64bit linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list